@@ -1,4 +1,5 @@
 #!/bin/bash
+# arglist.sh
 # Invoke this script with several arguments, such as "one two three".
 
 E_BADARGS=65
@@ -11,7 +12,7 @@ fi
 
 echo
 
-index=1
+index=1          # Initialize count.
 
 echo "Listing args with \"\$*\":"
 for arg in "$*"  # Doesn't work properly if "$*" isn't quoted.
@@ -23,7 +24,8 @@ echo "Entire arg list seen as single word."
 
 echo
 
-index=1
+index=1          # Reset count.
+                 # What happens if you forget to do this?
 
 echo "Listing args with \"\$@\":"
 for arg in "$@"
@@ -35,4 +37,14 @@ echo "Arg list seen as separate words."
 
 echo
 
+index=1          # Reset count.
+
+echo "Listing args with \$* (unquoted):"
+for arg in $*
+do
+  echo "Arg #$index = $arg"
+  let "index+=1"
+done             # Unquoted $* sees arguments as separate words. 
+echo "Arg list seen as separate words."
+
 exit 0
