@@ -1,12 +1,16 @@
 #!/bin/bash
+# badname.sh
 
 # Delete filenames in current directory containing bad characters.
 
 for filename in *
 do
-badname=`echo "$filename" | sed -n /[\+\{\;\"\\\=\?~\(\)\<\>\&\*\|\$]/p`
-# Files containing those nasties:     + { ; " \ = ? ~ ( ) < > & * | $
-rm $badname 2>/dev/null    # So error messages deep-sixed.
+  badname=`echo "$filename" | sed -n /[\+\{\;\"\\\=\?~\(\)\<\>\&\*\|\$]/p`
+# badname=`echo "$filename" | sed -n '/[+{;"\=?~()&lt;&gt;&*|$]/p'`  also works.
+# Deletes files containing these nasties:     + { ; " \ = ? ~ ( ) < > & * | $
+#
+  rm $badname 2>/dev/null
+#             ^^^^^^^^^^^ Error messages deep-sixed.
 done
 
 # Now, take care of files containing all manner of whitespace.
@@ -21,5 +25,4 @@ exit 0
 
 # An alternative to the above script:
 find . -name '*[+{;"\\=?~()&lt;&gt;&*|$ ]*' -exec rm -f '{}' \;
-exit 0
 # (Thanks, S.C.)
