@@ -14,7 +14,7 @@
 ARGS=2
 E_BADARGS=65
 
-if [ $# -ne $ARGS ]
+if [ $# -ne "$ARGS" ]
 then
   echo "Usage: `basename $0` old_file_suffix new_file_suffix"
   exit $E_BADARGS
@@ -24,8 +24,8 @@ for filename in *.$1
 # Traverse list of files ending with 1st argument.
 do
   mv $filename ${filename%$1}$2
-  # Strip off part of filename matching 1st argument,
-  # then append 2nd argument.
+  #  Strip off part of filename matching 1st argument,
+  #+ then append 2nd argument.
 done
 
 exit 0
