@@ -12,9 +12,11 @@ setvar_rot_13()              # "rot13" scrambling
 setvar_rot_13 var "foobar"   # Run "foobar" through rot13.
 echo $var                    # sbbone
 
-echo $var | tr a-z n-za-m    # foobar
+setvar_rot_13 var "$var"     # Run "sbbone" through rot13.
                              # Back to original variable.
+echo $var                    # foobar
 
 # This example by Stephane Chazelas.
+# Modified by document author.
 
 exit 0
